/*
 * Copyright (C) 2021 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1.  Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 * 2.  Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS BE LIABLE FOR
 * ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "config.h"
#if USE(LIBWEBRTC) && PLATFORM(COCOA) && ENABLE(GPU_PROCESS)
#include "LibWebRTCCodecsProxy.h"

#include "ArgumentCoders.h"
#include "DataReference.h"
#include "Decoder.h"
#include "HandleMessage.h"
#include "LibWebRTCCodecsProxyMessages.h"
#include "RTCDecoderIdentifier.h"
#include "RTCEncoderIdentifier.h"
#include "WebCoreArgumentCoders.h"
#include <WebCore/RemoteVideoSample.h>
#include <utility>
#include <wtf/Vector.h>
#include <wtf/text/WTFString.h>

namespace WebKit {

void LibWebRTCCodecsProxy::didReceiveMessage(IPC::Connection& connection, IPC::Decoder& decoder)
{
    if (decoder.messageName() == Messages::LibWebRTCCodecsProxy::CreateH264Decoder::name())
        return IPC::handleMessage<Messages::LibWebRTCCodecsProxy::CreateH264Decoder>(decoder, this, &LibWebRTCCodecsProxy::createH264Decoder);
    if (decoder.messageName() == Messages::LibWebRTCCodecsProxy::CreateH265Decoder::name())
        return IPC::handleMessage<Messages::LibWebRTCCodecsProxy::CreateH265Decoder>(decoder, this, &LibWebRTCCodecsProxy::createH265Decoder);
    if (decoder.messageName() == Messages::LibWebRTCCodecsProxy::CreateVP9Decoder::name())
        return IPC::handleMessage<Messages::LibWebRTCCodecsProxy::CreateVP9Decoder>(decoder, this, &LibWebRTCCodecsProxy::createVP9Decoder);
    if (decoder.messageName() == Messages::LibWebRTCCodecsProxy::ReleaseDecoder::name())
        return IPC::handleMessage<Messages::LibWebRTCCodecsProxy::ReleaseDecoder>(decoder, this, &LibWebRTCCodecsProxy::releaseDecoder);
    if (decoder.messageName() == Messages::LibWebRTCCodecsProxy::DecodeFrame::name())
        return IPC::handleMessage<Messages::LibWebRTCCodecsProxy::DecodeFrame>(decoder, this, &LibWebRTCCodecsProxy::decodeFrame);
    if (decoder.messageName() == Messages::LibWebRTCCodecsProxy::SetFrameSize::name())
        return IPC::handleMessage<Messages::LibWebRTCCodecsProxy::SetFrameSize>(decoder, this, &LibWebRTCCodecsProxy::setFrameSize);
    if (decoder.messageName() == Messages::LibWebRTCCodecsProxy::CreateEncoder::name())
        return IPC::handleMessage<Messages::LibWebRTCCodecsProxy::CreateEncoder>(decoder, this, &LibWebRTCCodecsProxy::createEncoder);
    if (decoder.messageName() == Messages::LibWebRTCCodecsProxy::ReleaseEncoder::name())
        return IPC::handleMessage<Messages::LibWebRTCCodecsProxy::ReleaseEncoder>(decoder, this, &LibWebRTCCodecsProxy::releaseEncoder);
    if (decoder.messageName() == Messages::LibWebRTCCodecsProxy::InitializeEncoder::name())
        return IPC::handleMessage<Messages::LibWebRTCCodecsProxy::InitializeEncoder>(decoder, this, &LibWebRTCCodecsProxy::initializeEncoder);
    if (decoder.messageName() == Messages::LibWebRTCCodecsProxy::EncodeFrame::name())
        return IPC::handleMessage<Messages::LibWebRTCCodecsProxy::EncodeFrame>(decoder, this, &LibWebRTCCodecsProxy::encodeFrame);
    if (decoder.messageName() == Messages::LibWebRTCCodecsProxy::SetEncodeRates::name())
        return IPC::handleMessage<Messages::LibWebRTCCodecsProxy::SetEncodeRates>(decoder, this, &LibWebRTCCodecsProxy::setEncodeRates);
    if (decoder.messageName() == Messages::LibWebRTCCodecsProxy::SetRTCLoggingLevel::name())
        return IPC::handleMessage<Messages::LibWebRTCCodecsProxy::SetRTCLoggingLevel>(decoder, this, &LibWebRTCCodecsProxy::setRTCLoggingLevel);
    UNUSED_PARAM(connection);
    UNUSED_PARAM(decoder);
#if ENABLE(IPC_TESTING_API)
    if (connection.ignoreInvalidMessageForTesting())
        return;
#endif // ENABLE(IPC_TESTING_API)
    ASSERT_NOT_REACHED_WITH_MESSAGE("Unhandled message %s to %" PRIu64, description(decoder.messageName()), decoder.destinationID());
}

} // namespace WebKit

#endif // USE(LIBWEBRTC) && PLATFORM(COCOA) && ENABLE(GPU_PROCESS)
